@@ -18,8 +18,3 @@
 #define errf(fmt, args...) _err(warnf, fmt , ## args)
 #define errp(fmt, args...) _err(warnp, fmt , ## args)
 #define errfp(fmt, args...) _err(warnfp, fmt, ## args)
-#define ARRAY_SIZE(arr) (sizeof(arr) / sizeof(*arr))
-
-#ifndef BUFSIZE
-# define BUFSIZE 8192
-#endif
