@@ -592,7 +592,8 @@ _q_static void read_portage_env_file(const char *configroot, const char *file, e
 	FILE *fp;
 	char *buf, *s, *p;
 
-	IF_DEBUG(fprintf(stderr, "profile %s\n", file));
+	if (getenv("DEBUG"))
+		fprintf(stderr, "profile %s\n", file);
 
 	configroot_len = strlen(configroot);
 	file_len = strlen(file);
@@ -885,7 +886,7 @@ void initialize_portage_env(void)
 		}
 	}
 
-	if (getenv("DEBUG") IF_DEBUG(|| 1)) {
+	if (getenv("DEBUG")) {
 		for (i = 0; vars_to_read[i].name; ++i) {
 			var = &vars_to_read[i];
 			fprintf(stderr, "%s = ", var->name);
@@ -905,7 +906,10 @@ void initialize_portage_env(void)
 		portroot[var->value_len + 1] = '\0';
 	}
 
+	char *orig_main_overlay = main_overlay;
 	read_repos_conf(configroot, CONFIG_EPREFIX "etc/portage/repos.conf");
+	if (orig_main_overlay != main_overlay)
+		free(orig_main_overlay);
 	if (array_cnt(overlays) == 0)
 		xarraypush_str(overlays, main_overlay);
 
@@ -1067,15 +1071,19 @@ ret:
 void reinitialize_as_needed(void)
 {
 	size_t n;
-	const char *overlay;
+	const char *overlay, *ret = ret;
 
 	if (reinitialize)
-		array_for_each(overlays, n, overlay)
-			initialize_flat(overlay, CACHE_EBUILD, true);
+		array_for_each(overlays, n, overlay) {
+			ret = initialize_flat(overlay, CACHE_EBUILD, true);
+			IF_DEBUG(free((void *)ret));
+		}
 
 	if (reinitialize_metacache)
-		array_for_each(overlays, n, overlay)
-			initialize_flat(overlay, CACHE_METADATA, true);
+		array_for_each(overlays, n, overlay) {
+			ret = initialize_flat(overlay, CACHE_METADATA, true);
+			IF_DEBUG(free((void *)ret));
+		}
 }
 
 typedef struct {
@@ -1380,7 +1388,6 @@ _q_static queue *get_vdb_atoms(int fullcpv)
 void cleanup(void)
 {
 	reinitialize_as_needed();
-	fclose(stderr);
 }
 
 int main(int argc, char **argv)
