@@ -21,9 +21,6 @@ int qtemp_main(int argc, char **argv)
 {
 	int i;
 
-	DBG("argc=%d argv[0]=%s argv[1]=%s",
-	    argc, argv[0], argc > 1 ? argv[1] : "NULL?");
-
 	while ((i = GETOPT_LONG(QTEMP, qtemp, "")) != -1) {
 		switch (i) {
 		COMMON_GETOPTS_CASES(qtemp)
